@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,20 +8,17 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
-#Enter data dir
+# Enter data dir
 cd ${data_dir}/bufr
 
-#Define a common label for all the tmp files
+# Define a common label for all the tmp files
 label="bufr_ls_test"
 
-#Create log file
 fLog=${label}".log"
 rm -f $fLog
 touch $fLog
-
-#Define tmp file
 fTmp=${label}".tmp.txt"
 rm -f $fTmp
 
@@ -34,9 +31,9 @@ for f in ${bufr_files} ; do
    ${tools_dir}/bufr_ls $f >> $fLog
 done
 
-#-------------------------------------------
+#-----------------
 # Test "-p" switch
-#-------------------------------------------
+#-----------------
 f="aaen_55.bufr"
 ref_ls=$f".ls.ref"
 res_ls=$f".ls.test"
@@ -44,19 +41,29 @@ REDIRECT=/dev/null
 
 ${tools_dir}/bufr_ls -p totalLength,bufrHeaderCentre,bufrHeaderSubCentre,masterTableNumber,masterTablesVersionNumber,localTablesVersionNumber,numberOfSubsets,localNumberOfObservations $f 2> $REDIRECT > $fTmp
 
-#Write the values into a file and compare with ref
+# Write the values into a file and compare with ref
 awk NR==3 $fTmp | awk '{split($0,a," "); for (i=1; i<=8; i++) print a[i]}' > $res_ls
 diff $ref_ls $res_ls
 
-#-------------------------------------------
-# Test reading from stdin
-#-------------------------------------------
-f="aaen_55.bufr"
-cat $f | ${tools_dir}/bufr_ls -
-result1=`${tools_dir}/bufr_get -p numberOfSubsets $f`
-result2=`cat $f | ${tools_dir}/bufr_get -p numberOfSubsets -`
-[ "$result1" = "$result2" ]
+# ------------------------
+# Test printing array key
+# ------------------------
+set +e
+${tools_dir}/bufr_ls -p numericValues $f >$fTmp 2>&1
+status=$?
+set -e
+[ $status -ne 0 ]
+cat $fTmp
+grep -q "Passed array is too small" $fTmp
 
 
+# ------------------------
+# Test setting header key
+# ------------------------
+${tools_dir}/bufr_ls -s satelliteID=313 -p satelliteID aaen_55.bufr > $fTmp
+grep -q "313" $fTmp
+
+
+# Clean up
 rm -f $fLog $res_ls 
 rm -f $fTmp
